@@ -9,6 +9,11 @@
 ;; For the tests you need /usr/bin/env. Inside the container:
 ;;
 ;;   mkdir -p /usr/bin ; ln -s $GUIX_ENVIRONMENT/bin/env /usr/bin/env
+;;
+;;   meson build/ --buildtype debug
+;;   cd build
+;;   ninja
+;;   ninja test
 
 (use-modules
   ((guix licenses) #:prefix license:)
@@ -22,12 +27,14 @@
   (gnu packages bioinformatics)
   (gnu packages build-tools)
   (gnu packages curl)
+  (gnu packages gcc)
   (gnu packages llvm)
   (gnu packages ninja)
   (gnu packages parallel)
   (gnu packages perl)
   (gnu packages perl6)
   (gnu packages pkg-config)
+  (gnu packages python)
   (srfi srfi-1)
   (ice-9 popen)
   (ice-9 rdelim))
@@ -45,12 +52,13 @@
     (build-system meson-build-system)
     (propagated-inputs
      `(("perl" ,perl)          ; for testing
+       ("python" ,python)          ; for testing
        ("grep" ,grep)          ; for testing
        ("samtools" ,samtools)  ; for testing
-       ("vcflib" ,vcflib)      ; for freebayes-parallel
+       ("vcflib" ,vcflib)      ; for testing freebayes-parallel
        ("which" ,which)        ; for version
-       ("htslib" ,htslib)      ; does work, but lacks codecs
-       ("tabixpp" ,tabixpp)    ; for htslib
+       ; ("htslib" ,htslib)      ; does work, but lacks codecs
+       ; ("tabixpp" ,tabixpp)    ; for htslib
        ("bzip2-static" ,bzip2 "static")    ; libz2 part of htslib for static builds
        ("xz-static" ,xz "static")     ; for static builds
        ("zlib-static" ,zlib "static")))
@@ -64,6 +72,7 @@
      `(
        ;; ("clang" ,clang)      ; add this to test clang builds
        ;; ("lld" ,lld)          ; add this to test clang builds
+       ("gcc" ,gcc-11)
        ("bc" ,bc)               ; for tests
        ("coreutils" ,coreutils) ; for echo and env in tests
        ("curl" ,curl)
